netapp_ontap.resources.cluster_ssh_server API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cluster_ssh_server`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

ONTAP supports SSH server that can be accessed from any standard SSH client. A user account needs to be associated with SSH as the application (refer the documentation for api/security/accounts `DOC /security/accounts`). Upon connecting from a client, the user is authenticated and a command line shell is presented.
This endpoint is used to retrieve or modify the SSH configuration at the cluster level. The configuration consists of SSH security parameters (security algorithms and maximum authentication retry attempts allowed before closing the connection) and SSH connection limits.
The security algorithms include SSH key exchange algorithms, ciphers for payload encryption, and MAC algorithms. This configuration is the default for all newly created SVMs; existing SVM configurations are not impacted. The SSH connection limits include maximum connections per second, maximum simultaneous sessions from the same client host, and overall maximum SSH connections at any given point in time. The connection limits are per node and will be the same for all nodes in the cluster.

## Examples

### Updating the SSH security parameters

Specify the algorithms in the body of the PATCH request.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterSshServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterSshServer()
        resource.ciphers = ["aes256_ctr", "aes192_ctr"]
        resource.key_exchange_algorithms = [
            "diffie_hellman_group_exchange_sha256",
            "diffie_hellman_group14_sha1",
        ]
        resource.mac_algorithms = ["hmac_sha2_512_etm", "umac_128_etm"]
        resource.max_authentication_retry_count = 3
        resource.patch()

### Updating the SSH connection limits

Specify the connection limits in the body of the PATCH request.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterSshServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterSshServer()
        resource.connections_per_second = 8
        resource.max_instances = 10
        resource.per_source_limit = 5
        resource.patch()

### Retrieving the cluster SSH server configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterSshServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterSshServer()
        resource.get()
        print(resource)

Try it out

    ClusterSshServer(
        {
            "ciphers": ["aes256_ctr", "aes192_ctr"],
            "key_exchange_algorithms": [
                "diffie_hellman_group_exchange_sha256",
                "diffie_hellman_group14_sha1",
            ],
            "max_authentication_retry_count": 3,
            "_links": {"self": {"href": "/api/security/ssh"}},
            "per_source_limit": 5,
            "max_instances": 10,
            "connections_per_second": 8,
            "mac_algorithms": ["hmac_sha2_512_etm", "umac_128_etm"],
        }
    )

## Classes

`class ClusterSshServer (*args, **kwargs)`

  Allows interaction with ClusterSshServer objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the cluster SSH server ciphers, MAC algorithms, key exchange algorithms, and connection limits.

    ### Related ONTAP commands

    - `security ssh`
    - `security protocol ssh`

    ### Learn more

    - `DOC /security/ssh`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the SSH server setting for a cluster.

    ### Optional parameters

    - `ciphers` - Encryption algorithms for the payload
    - `key_exchange_algorithms` - SSH key exchange algorithms
    - `mac_algorithms` - MAC algorithms
    - `max_authentication_retry_count` - Maximum authentication retries allowed before closing the connection
    - `connections_per_second` - Maximum allowed connections per second
    - `max_instances` - Maximum allowed connections per node
    - `per_source_limit` - Maximum allowed connections from the same client host

    ### Related ONTAP commands

    - `security ssh`
    - `security protocol ssh`

    ### Learn more

    - `DOC /security/ssh`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ClusterSshServerSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterSshServer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ciphers GET POST PATCH`

    Ciphers for encrypting the data.

    Example: ["aes256_ctr","aes192_ctr","aes128_ctr"]

  `connections_per_second GET POST PATCH`

    Maximum connections allowed per second.

  `key_exchange_algorithms GET POST PATCH`

    Key exchange algorithms.

    Example: ["diffie_hellman_group_exchange_sha256","diffie_hellman_group14_sha1"]

  `links GET`

    The links field of the cluster_ssh_server.

  `mac_algorithms GET POST PATCH`

    MAC algorithms.

    Example: ["hmac_sha1","hmac_sha2_512_etm"]

  `max_authentication_retry_count GET POST PATCH`

    Maximum authentication retries allowed before closing the connection.

  `max_instances GET POST PATCH`

    Maximum possible simultaneous connections.

  `per_source_limit GET POST PATCH`

    Maximum connections from the same client host.